==> occlib-0.3.6.tar.gz: occlib-0.3.6/README.md <==
<h1 align="center">occlib-py</h1>
<p align="center">
    <img height=150 class="heightSet" align="center" src="https://www.python.org/static/community_logos/python-logo-generic.svg"/>
</p>
<p align="center">A Python Library Template</p>
<p align="center">
    <a href="https://dev.azure.com/peake100/Open%20Cinema%20Collective/_build?definitionId=13"><img src="https://dev.azure.com/peake100/Open%20Cinema%20Collective/_apis/build/status/occlib-py?repoName=opencinemac%2Focclib-py&branchName=dev" alt="click to see build pipeline"></a>
    <a href="https://dev.azure.com/peake100/Open%20Cinema%20Collective/_build?definitionId=13"><img src="https://img.shields.io/azure-devops/tests/peake100/Open%20Cinema%20Collective/13/dev?compact_message" alt="click to see build pipeline"></a>
    <a href="https://dev.azure.com/peake100/Open%20Cinema%20Collective/_build?definitionId=13"><img src="https://img.shields.io/azure-devops/coverage/peake100/Open%20Cinema%20Collective/13/dev?compact_message" alt="click to see build pipeline"></a>
</p>
<p align="center">
    <a href="https://codeclimate.com/github/opencinemac/occlib-py/maintainability"><img src="https://api.codeclimate.com/v1/badges/705d052bebf3cdf1256a/maintainability" /></a>
</p>
<p align="center">
    <a href="https://github.com/opencinemac/occlib-py/"><img src="https://img.shields.io/pypi/pyversions/vtc" alt="Documentation"></a>
    <a href="https://pypi.org/project/occlib/"><img src="https://badge.fury.io/py/occlib.svg" alt="PyPI version" height="18"></a>
    <a href="https://opencinemac.github.io/occlib-py/"><img src="https://img.shields.io/badge/docs-github.io-blue" alt="Documentation"></a>
</p>

# Basic Overview

occlib is the Open Cinema Collective's python Library template.

occlib comes pre-built with a number of tools for formatting, linting and 
testing.

## Installation

``pip install occlib``

## Getting Started
For full documentation:
[read the docs](https://opencinemac.github.io/occlib-py/).

For library development guide, 
[read the docs](https://opencinemac.github.io/occlib-py/).

### Prerequisites

Python 3.8+

## Authors

* **Billy Peake** - *Initial work*

==> occlib-0.3.8.tar.gz: occlib-0.3.8/README.md <==
<h1 align="center">occlib-py</h1>
<p align="center">
    <img height=150 class="heightSet" align="center" src="https://www.python.org/static/community_logos/python-logo-generic.svg"/>
</p>
<p align="center">A Python Library Template</p>
<p align="center">
    <a href="https://dev.azure.com/peake100/Open%20Cinema%20Collective/_build?definitionId=13"><img src="https://dev.azure.com/peake100/Open%20Cinema%20Collective/_apis/build/status/occlib-py?repoName=opencinemac%2Focclib-py&branchName=dev" alt="click to see build pipeline"></a>
    <a href="https://dev.azure.com/peake100/Open%20Cinema%20Collective/_build?definitionId=13"><img src="https://img.shields.io/azure-devops/tests/peake100/Open%20Cinema%20Collective/13/dev?compact_message" alt="click to see build pipeline"></a>
    <a href="https://dev.azure.com/peake100/Open%20Cinema%20Collective/_build?definitionId=13"><img src="https://img.shields.io/azure-devops/coverage/peake100/Open%20Cinema%20Collective/13/dev?compact_message" alt="click to see build pipeline"></a>
</p>
<p align="center">
    <a href="https://codeclimate.com/github/opencinemac/occlib-py/maintainability"><img src="https://api.codeclimate.com/v1/badges/705d052bebf3cdf1256a/maintainability" /></a>
    <a href="https://github.com/psf/black"><img src="https://img.shields.io/badge/code%20style-black-000000.svg" /></a>
</p>
<p align="center">
    <a href="https://github.com/opencinemac/occlib-py/"><img src="https://img.shields.io/pypi/pyversions/vtc" alt="Documentation"></a>
    <a href="https://pypi.org/project/occlib/"><img src="https://badge.fury.io/py/occlib.svg" alt="PyPI version" height="18"></a>
    <a href="https://opencinemac.github.io/occlib-py/"><img src="https://img.shields.io/badge/docs-github.io-blue" alt="Documentation"></a>
</p>

# Basic Overview

occlib is the Open Cinema Collective's python Library template.

occlib comes pre-built with a number of tools for formatting, linting and 
testing.

## Installation

``pip install occlib``

## Getting Started
For full documentation:
[read the docs](https://opencinemac.github.io/occlib-py/).

For library development guide, 
[read the docs](https://opencinemac.github.io/occlib-py/).

### Prerequisites

Python 3.8+

## Authors

* **Billy Peake** - *Initial work*
